/**
 * Copyright (c) Facebook, Inc. and its affiliates.
 *
 * This source code is licensed under the MIT license found in the
 * LICENSE file in the root directory of this source tree.
 */
import React from "react";
import {useThemeConfig} from "@docusaurus/theme-common";
import FooterLinks from "@theme/Footer/Links";
import FooterLogo from "@theme/Footer/Logo";
import FooterCopyright from "@theme/Footer/Copyright";
import FooterLayout from "@theme/Footer/Layout";
import { FaLinkedin, FaFacebook, FaTwitter } from "react-icons/fa";
import FroggitLogo from "@site/static/img/logo_froggit_blanc.png";
import GitlabLogo from "@site/static/img/gitlab-logo.png";



function Footer() {
  const {footer} = useThemeConfig();

  if (!footer) {
    return null;
  }

  const {copyright, icons, links, logo, style, FooterIcons} = footer;
  return (
    <>
      <div className="footer">
      <img src="https://tracker.metricool.com/c3po.jpg?hash=d8939750b2ccb6164c7ec5649ac8005e"/>
        <div className="footer-container">
          <a href="https://www.linkedin.com/company/lydrafr/" target="_blank" rel="noreferrer">
            <div className="linkedin-icon">
              <FaLinkedin className="footer-icons" />
            </div>
          </a>
          
          <a href="https://twitter.com/art_devops" target="_blank" rel="noreferrer">
            <div className="twitter-icon">
              <FaTwitter className="footer-icons" />
            </div>
          </a>

          <a href="https://www.facebook.com/Lydrafr/" target="_blank" rel="noreferrer">
            <div className="facebook-icon">
              <FaFacebook className="footer-icons" />
            </div>
          </a>

          <a href="https://lab.frogg.it/lydra" target="_blank" rel="noreferrer">
            <div className="froggit-icon">
              <img className="footer-icons" src={FroggitLogo} />
            </div>
          </a>

          <a href="https://gitlab.com/lydra" target="_blank" rel="noreferrer">
            <div className="gitlab-icon">
              <img className="footer-icons" src={GitlabLogo} />
            </div>
          </a>

        </div>

        <div>
          <FooterLayout
            icons={icons && <FooterIcons icons={icons} />}
            style={style}
            links={links && links.length > 0 && <FooterLinks links={links} />}
            logo={logo && <FooterLogo logo={logo} />}
            copyright={copyright && <FooterCopyright copyright={copyright} />}
          />
        </div>
      </div>
    </>
  );
}

export default React.memo(Footer);
